# Python Library for the EU ASSISTANT Project

## Library Description

This library contains the following sublibraries:
1. [**graphdb**](#graphdb)
2. [**production_system**](#production-system)

### GraphDB
Enables using the Rest API for 
[OntoText GraphDB](https://www.ontotext.com/products/graphdb/) 
to Up-/Download files to
and from the selected graph inside a repository. 

With OntoRefine you can upload a file and map the keywords, preprocessing the data for uploading it to a graph.


### Production System

Enables reading ProductionSystem file from GraphDB and turning it into valid json format.


---
## Change History

**0.2**:
- Create new sublibrary *production_system*
- Remove prints from *graphdb*

**0.1.1**:
- Update graphdb download

**0.1**:
- Create library
- Create new sublibrary *graphdb*

---
For more information about the project go to the [ASSISTANT Homepage](https://assistant-project.eu).

